Module node

Module node 

Node identifiers for graph subjects and objects.

A NodeId uniquely identifies a node (a subject or an object) in the graph.

Enums

NodeId
A unique identifier for a node in the graph, which can be a subject or a named object.