pub struct GraphStats {
pub triple_count: usize,
pub subject_count: usize,
pub predicate_count: usize,
pub object_count: usize,
pub storage_bytes: usize,
}Expand description
Provides statistics about the contents and size of the graph.
Fields
triple_count: usizeThe total number of triples in the graph.
subject_count: usizeThe number of unique subjects.
predicate_count: usizeThe number of unique predicates.
object_count: usizeThe number of unique objects.
storage_bytes: usizeThe approximate size of the database on disk in bytes.